/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

/*─────────────────────────────────────────────────────────────────────────────
 *
 * THIS IS AUTOMATICALLY GENERATED CODE.  DO NOT MODIFY.
 *
 *─────────────────────────────────────────────────────────────────────────────
 */

#ifndef OME_XML_MODEL_DETECTOR_H
#define OME_XML_MODEL_DETECTOR_H

#include <algorithm>
#include <list>
#include <stdexcept>
#include <string>
#include <vector>

#include <ome/common/log.h>

#include <ome/common/xml/dom/Document.h>
#include <ome/common/xml/dom/Element.h>
#include <ome/common/xml/dom/Node.h>
#include <ome/common/xml/dom/NodeList.h>

#include <ome/xml/model/Instrument.h>
#include <ome/xml/model/ManufacturerSpec.h>
#include <ome/xml/model/enums/DetectorType.h>

namespace ome
{
  namespace xml
  {
    namespace model
    {

      // Forward declarations.
      class OMEModel;

      /**
       * Detector model object.
       */
      class Detector : public ManufacturerSpec
      {
      private:
        class Impl;
        /// Private implementation details.
        ome::compat::shared_ptr<Impl> impl;

      public:
        /// Default constructor.
        Detector();

        /**
         * Copy constructor.
         *
         * @param copy the Detector to copy.
         */
        Detector (const Detector& copy);

        /// Destructor.
        virtual
        ~Detector ();

        /**
         * Create a Detector model object from DOM element.
         *
         * @param element root of the XML DOM tree to from which to
         * construct the model object graph.
         * @param model handler for the OME model used to track
         * instances and references seen during the update.
         * @throws EnumerationException if there is an error
         * instantiating an enumeration during model object creation,
         * or ModelException if there are any consistency or validity
         * errors found during processing.
         *
         * @returns a new model object.
         */
        static ome::compat::shared_ptr< Detector>
        create(const common::xml::dom::Element& element,
               ome::xml::model::OMEModel& model);

        // Documented in superclass.
        const std::string&
        elementName() const;

        // Documented in superclass.
        bool
        validElementName(const std::string& name) const;


        // -- OMEModelObject API methods --

        /// @copydoc ome::xml::model::OMEModelObject::update
        virtual void
        update(const common::xml::dom::Element&  element,
               ome::xml::model::OMEModel& model);

      public:
        // -- Detector API methods --

        /// @copydoc ome::xml::model::OMEModelObject::link
        bool
        link (ome::compat::shared_ptr<Reference>& reference,
              ome::compat::shared_ptr< ome::xml::model::OMEModelObject>& object);

        /**
         * Get the Zoom property.
         *
         * @returns the Zoom property.
         */
        ome::compat::shared_ptr<double>
        getZoom ();

        /**
         * Get the Zoom property.
         *
         * @returns the Zoom property.
         */
        const ome::compat::shared_ptr<double>
        getZoom () const;

        /**
         * Set the Zoom property.
         *
         * @param zoom the value to set.
         */
        void
        setZoom (ome::compat::shared_ptr<double>& zoom);

        /**
         * Get the AmplificationGain property.
         *
         * @returns the AmplificationGain property.
         */
        ome::compat::shared_ptr<double>
        getAmplificationGain ();

        /**
         * Get the AmplificationGain property.
         *
         * @returns the AmplificationGain property.
         */
        const ome::compat::shared_ptr<double>
        getAmplificationGain () const;

        /**
         * Set the AmplificationGain property.
         *
         * @param amplificationGain the value to set.
         */
        void
        setAmplificationGain (ome::compat::shared_ptr<double>& amplificationGain);

        /**
         * Get the Gain property.
         *
         * @returns the Gain property.
         */
        ome::compat::shared_ptr<double>
        getGain ();

        /**
         * Get the Gain property.
         *
         * @returns the Gain property.
         */
        const ome::compat::shared_ptr<double>
        getGain () const;

        /**
         * Set the Gain property.
         *
         * @param gain the value to set.
         */
        void
        setGain (ome::compat::shared_ptr<double>& gain);

        /**
         * Get the Offset property.
         *
         * @returns the Offset property.
         */
        ome::compat::shared_ptr<double>
        getOffset ();

        /**
         * Get the Offset property.
         *
         * @returns the Offset property.
         */
        const ome::compat::shared_ptr<double>
        getOffset () const;

        /**
         * Set the Offset property.
         *
         * @param offset the value to set.
         */
        void
        setOffset (ome::compat::shared_ptr<double>& offset);

        /**
         * Get the Type property.
         *
         * @returns the Type property.
         */
        ome::compat::shared_ptr<ome::xml::model::enums::DetectorType>
        getType ();

        /**
         * Get the Type property.
         *
         * @returns the Type property.
         */
        const ome::compat::shared_ptr<ome::xml::model::enums::DetectorType>
        getType () const;

        /**
         * Set the Type property.
         *
         * @param type the value to set.
         */
        void
        setType (ome::compat::shared_ptr<ome::xml::model::enums::DetectorType>& type);

        /**
         * Get the ID property.
         *
         * @returns the ID property.
         */
        const std::string&
        getID () const;

        /**
         * Set the ID property.
         *
         * @param id the value to set.
         */
        void
        setID (const std::string& id);

        /**
         * Get the Voltage property.
         *
         * @returns the Voltage property.
         */
        ome::compat::shared_ptr<double>
        getVoltage ();

        /**
         * Get the Voltage property.
         *
         * @returns the Voltage property.
         */
        const ome::compat::shared_ptr<double>
        getVoltage () const;

        /**
         * Set the Voltage property.
         *
         * @param voltage the value to set.
         */
        void
        setVoltage (ome::compat::shared_ptr<double>& voltage);

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument ();

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        const ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument () const;

        /**
         * Set the Instrument property.
         *
         * @param instrument_BackReference the value to set.
         */
        void
        setInstrument (ome::compat::weak_ptr<ome::xml::model::Instrument>& instrument_BackReference);


        /// @copydoc ome::xml::model::OMEModelObject::asXMLElement
        virtual common::xml::dom::Element
        asXMLElement (common::xml::dom::Document& document) const;


      protected:
        // Documented in base class.
        virtual common::xml::dom::Element
        asXMLElementInternal (common::xml::dom::Document& document,
                              common::xml::dom::Element&  element) const;

      public:
       // Documented in superclass.
       const std::string&
       getXMLNamespace() const;
      };

    }
  }
}

#endif // OME_XML_MODEL_DETECTOR_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
