/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

/*─────────────────────────────────────────────────────────────────────────────
 *
 * THIS IS AUTOMATICALLY GENERATED CODE.  DO NOT MODIFY.
 *
 *─────────────────────────────────────────────────────────────────────────────
 */

#ifndef OME_XML_MODEL_DICHROIC_H
#define OME_XML_MODEL_DICHROIC_H

#include <algorithm>
#include <list>
#include <stdexcept>
#include <string>
#include <vector>

#include <ome/common/log.h>

#include <ome/common/xml/dom/Document.h>
#include <ome/common/xml/dom/Element.h>
#include <ome/common/xml/dom/Node.h>
#include <ome/common/xml/dom/NodeList.h>

#include <ome/xml/model/Instrument.h>
#include <ome/xml/model/ManufacturerSpec.h>

namespace ome
{
  namespace xml
  {
    namespace model
    {

      // Forward declarations.
      class FilterSet;
      class LightPath;
      class OMEModel;

      /**
       * Dichroic model object.
       */
      class Dichroic : public ManufacturerSpec
      {
      private:
        class Impl;
        /// Private implementation details.
        ome::compat::shared_ptr<Impl> impl;

      public:
        /// Default constructor.
        Dichroic();

        /**
         * Copy constructor.
         *
         * @param copy the Dichroic to copy.
         */
        Dichroic (const Dichroic& copy);

        /// Destructor.
        virtual
        ~Dichroic ();

        /**
         * Create a Dichroic model object from DOM element.
         *
         * @param element root of the XML DOM tree to from which to
         * construct the model object graph.
         * @param model handler for the OME model used to track
         * instances and references seen during the update.
         * @throws EnumerationException if there is an error
         * instantiating an enumeration during model object creation,
         * or ModelException if there are any consistency or validity
         * errors found during processing.
         *
         * @returns a new model object.
         */
        static ome::compat::shared_ptr< Dichroic>
        create(const common::xml::dom::Element& element,
               ome::xml::model::OMEModel& model);

        // Documented in superclass.
        const std::string&
        elementName() const;

        // Documented in superclass.
        bool
        validElementName(const std::string& name) const;


        // -- OMEModelObject API methods --

        /// @copydoc ome::xml::model::OMEModelObject::update
        virtual void
        update(const common::xml::dom::Element&  element,
               ome::xml::model::OMEModel& model);

      public:
        // -- Dichroic API methods --

        /// @copydoc ome::xml::model::OMEModelObject::link
        bool
        link (ome::compat::shared_ptr<Reference>& reference,
              ome::compat::shared_ptr< ome::xml::model::OMEModelObject>& object);

        /**
         * Get the ID property.
         *
         * @returns the ID property.
         */
        const std::string&
        getID () const;

        /**
         * Set the ID property.
         *
         * @param id the value to set.
         */
        void
        setID (const std::string& id);

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument ();

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        const ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument () const;

        /**
         * Set the Instrument property.
         *
         * @param instrument_BackReference the value to set.
         */
        void
        setInstrument (ome::compat::weak_ptr<ome::xml::model::Instrument>& instrument_BackReference);

        /**
         * Get size of linked FilterSet list.
         *
         * @returns the size of the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::FilterSet, ome::compat::weak_ptr>::type::size_type
        sizeOfLinkedFilterSetList () const;

        /**
         * Get the linked FilterSet list.
         *
         * @returns a reference to the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::FilterSet, ome::compat::weak_ptr>::type
        getLinkedFilterSetList () const;

        /**
         * Get linked FilterSet.
         *
         * @param index the index number of the FilterSet.
         * @returns a weak pointer to the FilterSet.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::FilterSet>&
        getLinkedFilterSet (OMEModelObject::indexed_container<ome::xml::model::FilterSet, ome::compat::weak_ptr>::type::size_type index) const;

        /**
         * Set linked FilterSet.
         *
         * @note The index must be valid.
         *
         * @param index the index number of the FilterSet.
         * @param filterSet_BackReference the FilterSet to set.
         * @returns a weak pointer to the FilterSet.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::FilterSet>&
        setLinkedFilterSet (OMEModelObject::indexed_container<ome::xml::model::FilterSet, ome::compat::weak_ptr>::type::size_type index,
                                     const ome::compat::shared_ptr<ome::xml::model::FilterSet>& filterSet_BackReference);

        /**
         * Link FilterSet.
         *
         * @param filterSet_BackReference the FilterSet to link.
         * @returns @c true if the object was added to the internal
         * filterSets list, otherwise @c false.
         *
         * @todo Why have a return value here; what is it used for?
         * Is this an artifact of the Java API?
         */
        bool
        linkFilterSet (const ome::compat::shared_ptr<ome::xml::model::FilterSet>& filterSet_BackReference);

        /**
         * Unlink FilterSet.
         *
         * @param filterSet_BackReference the FilterSet to unlink.
         *
         * @returns @c true if the FilterSet was unlinked, otherwise
         * @c false if the FilterSet was not linked and could hence not be
         * unlinked.
         *
         * @todo Does the return value serve any useful purpose?  Is
         * this also inherited Java API?
         * @todo Doesn't the removal break the indexing?
         * @todo Does the removal deal with multiple instances; we
         * aren't preventing duplicates on insertion.
         */
        bool
        unlinkFilterSet (const ome::compat::shared_ptr<ome::xml::model::FilterSet>& filterSet_BackReference);

        /**
         * Get size of linked LightPath list.
         *
         * @returns the size of the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::LightPath, ome::compat::weak_ptr>::type::size_type
        sizeOfLinkedLightPathList () const;

        /**
         * Get the linked LightPath list.
         *
         * @returns a reference to the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::LightPath, ome::compat::weak_ptr>::type
        getLinkedLightPathList () const;

        /**
         * Get linked LightPath.
         *
         * @param index the index number of the LightPath.
         * @returns a weak pointer to the LightPath.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::LightPath>&
        getLinkedLightPath (OMEModelObject::indexed_container<ome::xml::model::LightPath, ome::compat::weak_ptr>::type::size_type index) const;

        /**
         * Set linked LightPath.
         *
         * @note The index must be valid.
         *
         * @param index the index number of the LightPath.
         * @param lightPath_BackReference the LightPath to set.
         * @returns a weak pointer to the LightPath.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::LightPath>&
        setLinkedLightPath (OMEModelObject::indexed_container<ome::xml::model::LightPath, ome::compat::weak_ptr>::type::size_type index,
                                     const ome::compat::shared_ptr<ome::xml::model::LightPath>& lightPath_BackReference);

        /**
         * Link LightPath.
         *
         * @param lightPath_BackReference the LightPath to link.
         * @returns @c true if the object was added to the internal
         * lightPaths list, otherwise @c false.
         *
         * @todo Why have a return value here; what is it used for?
         * Is this an artifact of the Java API?
         */
        bool
        linkLightPath (const ome::compat::shared_ptr<ome::xml::model::LightPath>& lightPath_BackReference);

        /**
         * Unlink LightPath.
         *
         * @param lightPath_BackReference the LightPath to unlink.
         *
         * @returns @c true if the LightPath was unlinked, otherwise
         * @c false if the LightPath was not linked and could hence not be
         * unlinked.
         *
         * @todo Does the return value serve any useful purpose?  Is
         * this also inherited Java API?
         * @todo Doesn't the removal break the indexing?
         * @todo Does the removal deal with multiple instances; we
         * aren't preventing duplicates on insertion.
         */
        bool
        unlinkLightPath (const ome::compat::shared_ptr<ome::xml::model::LightPath>& lightPath_BackReference);


        /// @copydoc ome::xml::model::OMEModelObject::asXMLElement
        virtual common::xml::dom::Element
        asXMLElement (common::xml::dom::Document& document) const;


      protected:
        // Documented in base class.
        virtual common::xml::dom::Element
        asXMLElementInternal (common::xml::dom::Document& document,
                              common::xml::dom::Element&  element) const;

      public:
       // Documented in superclass.
       const std::string&
       getXMLNamespace() const;
      };

    }
  }
}

#endif // OME_XML_MODEL_DICHROIC_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
