/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

/*─────────────────────────────────────────────────────────────────────────────
 *
 * THIS IS AUTOMATICALLY GENERATED CODE.  DO NOT MODIFY.
 *
 *─────────────────────────────────────────────────────────────────────────────
 */

#ifndef OME_XML_MODEL_LIGHTPATH_H
#define OME_XML_MODEL_LIGHTPATH_H

#include <algorithm>
#include <list>
#include <stdexcept>
#include <string>
#include <vector>

#include <ome/common/log.h>

#include <ome/common/xml/dom/Document.h>
#include <ome/common/xml/dom/Element.h>
#include <ome/common/xml/dom/Node.h>
#include <ome/common/xml/dom/NodeList.h>

#include <ome/xml/model/Dichroic.h>
#include <ome/xml/model/detail/OMEModelObject.h>

namespace ome
{
  namespace xml
  {
    namespace model
    {

      // Forward declarations.
      class Filter;
      class OMEModel;

      /**
       * LightPath model object.
       */
      class LightPath : public detail::OMEModelObject
      {
      private:
        class Impl;
        /// Private implementation details.
        ome::compat::shared_ptr<Impl> impl;

      public:
        /// Default constructor.
        LightPath();

        /**
         * Copy constructor.
         *
         * @param copy the LightPath to copy.
         */
        LightPath (const LightPath& copy);

        /// Destructor.
        virtual
        ~LightPath ();

        /**
         * Create a LightPath model object from DOM element.
         *
         * @param element root of the XML DOM tree to from which to
         * construct the model object graph.
         * @param model handler for the OME model used to track
         * instances and references seen during the update.
         * @throws EnumerationException if there is an error
         * instantiating an enumeration during model object creation,
         * or ModelException if there are any consistency or validity
         * errors found during processing.
         *
         * @returns a new model object.
         */
        static ome::compat::shared_ptr< LightPath>
        create(const common::xml::dom::Element& element,
               ome::xml::model::OMEModel& model);

        // Documented in superclass.
        const std::string&
        elementName() const;

        // Documented in superclass.
        bool
        validElementName(const std::string& name) const;


        // -- OMEModelObject API methods --

        /// @copydoc ome::xml::model::OMEModelObject::update
        virtual void
        update(const common::xml::dom::Element&  element,
               ome::xml::model::OMEModel& model);

      public:
        // -- LightPath API methods --

        /// @copydoc ome::xml::model::OMEModelObject::link
        bool
        link (ome::compat::shared_ptr<Reference>& reference,
              ome::compat::shared_ptr< ome::xml::model::OMEModelObject>& object);

        /**
         * Get size of linked ExcitationFilter list.
         *
         * @returns the size of the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type
        sizeOfLinkedExcitationFilterList () const;

        /**
         * Get the linked ExcitationFilter list.
         *
         * @returns a reference to the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type
        getLinkedExcitationFilterList () const;

        /**
         * Get linked ExcitationFilter.
         *
         * @param index the index number of the ExcitationFilter.
         * @returns a weak pointer to the ExcitationFilter.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::Filter>&
        getLinkedExcitationFilter (OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type index) const;

        /**
         * Set linked ExcitationFilter.
         *
         * @note The index must be valid.
         *
         * @param index the index number of the ExcitationFilter.
         * @param excitationFilter the ExcitationFilter to set.
         * @returns a weak pointer to the ExcitationFilter.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::Filter>&
        setLinkedExcitationFilter (OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type index,
                                     const ome::compat::shared_ptr<ome::xml::model::Filter>& excitationFilter);

        /**
         * Link ExcitationFilter.
         *
         * @param excitationFilter the ExcitationFilter to link.
         * @returns @c true if the object was added to the internal
         * excitationFilterLinks list, otherwise @c false.
         *
         * @todo Why have a return value here; what is it used for?
         * Is this an artifact of the Java API?
         */
        bool
        linkExcitationFilter (const ome::compat::shared_ptr<ome::xml::model::Filter>& excitationFilter);

        /**
         * Unlink ExcitationFilter.
         *
         * @param excitationFilter the ExcitationFilter to unlink.
         *
         * @returns @c true if the ExcitationFilter was unlinked, otherwise
         * @c false if the ExcitationFilter was not linked and could hence not be
         * unlinked.
         *
         * @todo Does the return value serve any useful purpose?  Is
         * this also inherited Java API?
         * @todo Doesn't the removal break the indexing?
         * @todo Does the removal deal with multiple instances; we
         * aren't preventing duplicates on insertion.
         */
        bool
        unlinkExcitationFilter (const ome::compat::shared_ptr<ome::xml::model::Filter>& excitationFilter);

        /**
         * Get linked Dichroic.
         *
         * @returns the linked Dichroic.  The pointer may be
         * null.
         */
        ome::compat::weak_ptr<ome::xml::model::Dichroic>
        getLinkedDichroic ();

        /**
         * Get linked Dichroic.
         *
         * @returns the linked Dichroic.  The pointer may be
         * null.
         */
        const ome::compat::weak_ptr<ome::xml::model::Dichroic>
        getLinkedDichroic () const;

        /**
         * Link Dichroic.
         *
         * @param dichroic the Dichroic to link.
         */
        void
        linkDichroic (ome::compat::shared_ptr<ome::xml::model::Dichroic>& dichroic);

        /**
         * Unlink Dichroic.
         *
         * @param dichroic the Dichroic to unlink.
         *
         * @todo This method is fairly pointless since it's equivalent
         * to linking a null pointer.  It could call @c link(0)
         * internally.
         */
        void
        unlinkDichroic (ome::compat::shared_ptr<ome::xml::model::Dichroic>& dichroic);

        /**
         * Get size of linked EmissionFilter list.
         *
         * @returns the size of the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type
        sizeOfLinkedEmissionFilterList () const;

        /**
         * Get the linked EmissionFilter list.
         *
         * @returns a reference to the list.
         */
        OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type
        getLinkedEmissionFilterList () const;

        /**
         * Get linked EmissionFilter.
         *
         * @param index the index number of the EmissionFilter.
         * @returns a weak pointer to the EmissionFilter.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::Filter>&
        getLinkedEmissionFilter (OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type index) const;

        /**
         * Set linked EmissionFilter.
         *
         * @note The index must be valid.
         *
         * @param index the index number of the EmissionFilter.
         * @param emissionFilter the EmissionFilter to set.
         * @returns a weak pointer to the EmissionFilter.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::weak_ptr<ome::xml::model::Filter>&
        setLinkedEmissionFilter (OMEModelObject::indexed_container<ome::xml::model::Filter, ome::compat::weak_ptr>::type::size_type index,
                                     const ome::compat::shared_ptr<ome::xml::model::Filter>& emissionFilter);

        /**
         * Link EmissionFilter.
         *
         * @param emissionFilter the EmissionFilter to link.
         * @returns @c true if the object was added to the internal
         * emissionFilterLinks list, otherwise @c false.
         *
         * @todo Why have a return value here; what is it used for?
         * Is this an artifact of the Java API?
         */
        bool
        linkEmissionFilter (const ome::compat::shared_ptr<ome::xml::model::Filter>& emissionFilter);

        /**
         * Unlink EmissionFilter.
         *
         * @param emissionFilter the EmissionFilter to unlink.
         *
         * @returns @c true if the EmissionFilter was unlinked, otherwise
         * @c false if the EmissionFilter was not linked and could hence not be
         * unlinked.
         *
         * @todo Does the return value serve any useful purpose?  Is
         * this also inherited Java API?
         * @todo Doesn't the removal break the indexing?
         * @todo Does the removal deal with multiple instances; we
         * aren't preventing duplicates on insertion.
         */
        bool
        unlinkEmissionFilter (const ome::compat::shared_ptr<ome::xml::model::Filter>& emissionFilter);


        /// @copydoc ome::xml::model::OMEModelObject::asXMLElement
        virtual common::xml::dom::Element
        asXMLElement (common::xml::dom::Document& document) const;


      protected:
        // Documented in base class.
        virtual common::xml::dom::Element
        asXMLElementInternal (common::xml::dom::Document& document,
                              common::xml::dom::Element&  element) const;

      public:
       // Documented in superclass.
       const std::string&
       getXMLNamespace() const;
      };

    }
  }
}

#endif // OME_XML_MODEL_LIGHTPATH_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
