/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

/*─────────────────────────────────────────────────────────────────────────────
 *
 * THIS IS AUTOMATICALLY GENERATED CODE.  DO NOT MODIFY.
 *
 *─────────────────────────────────────────────────────────────────────────────
 */

#ifndef OME_XML_MODEL_OBJECTIVE_H
#define OME_XML_MODEL_OBJECTIVE_H

#include <algorithm>
#include <list>
#include <stdexcept>
#include <string>
#include <vector>

#include <ome/common/log.h>

#include <ome/common/xml/dom/Document.h>
#include <ome/common/xml/dom/Element.h>
#include <ome/common/xml/dom/Node.h>
#include <ome/common/xml/dom/NodeList.h>

#include <ome/xml/model/Instrument.h>
#include <ome/xml/model/ManufacturerSpec.h>
#include <ome/xml/model/enums/Correction.h>
#include <ome/xml/model/enums/Immersion.h>

namespace ome
{
  namespace xml
  {
    namespace model
    {

      // Forward declarations.
      class OMEModel;

      /**
       * Objective model object.
       */
      class Objective : public ManufacturerSpec
      {
      private:
        class Impl;
        /// Private implementation details.
        ome::compat::shared_ptr<Impl> impl;

      public:
        /// Default constructor.
        Objective();

        /**
         * Copy constructor.
         *
         * @param copy the Objective to copy.
         */
        Objective (const Objective& copy);

        /// Destructor.
        virtual
        ~Objective ();

        /**
         * Create a Objective model object from DOM element.
         *
         * @param element root of the XML DOM tree to from which to
         * construct the model object graph.
         * @param model handler for the OME model used to track
         * instances and references seen during the update.
         * @throws EnumerationException if there is an error
         * instantiating an enumeration during model object creation,
         * or ModelException if there are any consistency or validity
         * errors found during processing.
         *
         * @returns a new model object.
         */
        static ome::compat::shared_ptr< Objective>
        create(const common::xml::dom::Element& element,
               ome::xml::model::OMEModel& model);

        // Documented in superclass.
        const std::string&
        elementName() const;

        // Documented in superclass.
        bool
        validElementName(const std::string& name) const;


        // -- OMEModelObject API methods --

        /// @copydoc ome::xml::model::OMEModelObject::update
        virtual void
        update(const common::xml::dom::Element&  element,
               ome::xml::model::OMEModel& model);

      public:
        // -- Objective API methods --

        /// @copydoc ome::xml::model::OMEModelObject::link
        bool
        link (ome::compat::shared_ptr<Reference>& reference,
              ome::compat::shared_ptr< ome::xml::model::OMEModelObject>& object);

        /**
         * Get the Iris property.
         *
         * @returns the Iris property.
         */
        ome::compat::shared_ptr<bool>
        getIris ();

        /**
         * Get the Iris property.
         *
         * @returns the Iris property.
         */
        const ome::compat::shared_ptr<bool>
        getIris () const;

        /**
         * Set the Iris property.
         *
         * @param iris the value to set.
         */
        void
        setIris (ome::compat::shared_ptr<bool>& iris);

        /**
         * Get the WorkingDistance property.
         *
         * @returns the WorkingDistance property.
         */
        ome::compat::shared_ptr<double>
        getWorkingDistance ();

        /**
         * Get the WorkingDistance property.
         *
         * @returns the WorkingDistance property.
         */
        const ome::compat::shared_ptr<double>
        getWorkingDistance () const;

        /**
         * Set the WorkingDistance property.
         *
         * @param workingDistance the value to set.
         */
        void
        setWorkingDistance (ome::compat::shared_ptr<double>& workingDistance);

        /**
         * Get the Immersion property.
         *
         * @returns the Immersion property.
         */
        ome::compat::shared_ptr<ome::xml::model::enums::Immersion>
        getImmersion ();

        /**
         * Get the Immersion property.
         *
         * @returns the Immersion property.
         */
        const ome::compat::shared_ptr<ome::xml::model::enums::Immersion>
        getImmersion () const;

        /**
         * Set the Immersion property.
         *
         * @param immersion the value to set.
         */
        void
        setImmersion (ome::compat::shared_ptr<ome::xml::model::enums::Immersion>& immersion);

        /**
         * Get the Correction property.
         *
         * @returns the Correction property.
         */
        ome::compat::shared_ptr<ome::xml::model::enums::Correction>
        getCorrection ();

        /**
         * Get the Correction property.
         *
         * @returns the Correction property.
         */
        const ome::compat::shared_ptr<ome::xml::model::enums::Correction>
        getCorrection () const;

        /**
         * Set the Correction property.
         *
         * @param correction the value to set.
         */
        void
        setCorrection (ome::compat::shared_ptr<ome::xml::model::enums::Correction>& correction);

        /**
         * Get the LensNA property.
         *
         * @returns the LensNA property.
         */
        ome::compat::shared_ptr<double>
        getLensNA ();

        /**
         * Get the LensNA property.
         *
         * @returns the LensNA property.
         */
        const ome::compat::shared_ptr<double>
        getLensNA () const;

        /**
         * Set the LensNA property.
         *
         * @param lensNA the value to set.
         */
        void
        setLensNA (ome::compat::shared_ptr<double>& lensNA);

        /**
         * Get the NominalMagnification property.
         *
         * @returns the NominalMagnification property.
         */
        ome::compat::shared_ptr<double>
        getNominalMagnification ();

        /**
         * Get the NominalMagnification property.
         *
         * @returns the NominalMagnification property.
         */
        const ome::compat::shared_ptr<double>
        getNominalMagnification () const;

        /**
         * Set the NominalMagnification property.
         *
         * @param nominalMagnification the value to set.
         */
        void
        setNominalMagnification (ome::compat::shared_ptr<double>& nominalMagnification);

        /**
         * Get the CalibratedMagnification property.
         *
         * @returns the CalibratedMagnification property.
         */
        ome::compat::shared_ptr<double>
        getCalibratedMagnification ();

        /**
         * Get the CalibratedMagnification property.
         *
         * @returns the CalibratedMagnification property.
         */
        const ome::compat::shared_ptr<double>
        getCalibratedMagnification () const;

        /**
         * Set the CalibratedMagnification property.
         *
         * @param calibratedMagnification the value to set.
         */
        void
        setCalibratedMagnification (ome::compat::shared_ptr<double>& calibratedMagnification);

        /**
         * Get the ID property.
         *
         * @returns the ID property.
         */
        const std::string&
        getID () const;

        /**
         * Set the ID property.
         *
         * @param id the value to set.
         */
        void
        setID (const std::string& id);

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument ();

        /**
         * Get the Instrument property.
         *
         * @returns the Instrument property.
         */
        const ome::compat::weak_ptr<ome::xml::model::Instrument>
        getInstrument () const;

        /**
         * Set the Instrument property.
         *
         * @param instrument_BackReference the value to set.
         */
        void
        setInstrument (ome::compat::weak_ptr<ome::xml::model::Instrument>& instrument_BackReference);


        /// @copydoc ome::xml::model::OMEModelObject::asXMLElement
        virtual common::xml::dom::Element
        asXMLElement (common::xml::dom::Document& document) const;


      protected:
        // Documented in base class.
        virtual common::xml::dom::Element
        asXMLElementInternal (common::xml::dom::Document& document,
                              common::xml::dom::Element&  element) const;

      public:
       // Documented in superclass.
       const std::string&
       getXMLNamespace() const;
      };

    }
  }
}

#endif // OME_XML_MODEL_OBJECTIVE_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
